@@ -1,17 +1,21 @@
+import os
 from datetime import datetime
 from http import HTTPStatus
-from typing import Dict, Any
+from typing import Any, Dict
 
+from fastapi import APIRouter, Depends, Response, WebSocket, status
 from fps.hooks import register_router  # type: ignore
-from fastapi import APIRouter, WebSocket, Response, Depends, status
-
-from fps_auth.backends import cookie_authentication, current_user  # type: ignore
-from fps_auth.models import User  # type: ignore
-from fps_auth.db import get_user_db  # type: ignore
+from fps_auth.backends import current_user, get_jwt_strategy  # type: ignore
 from fps_auth.config import get_auth_config  # type: ignore
+from fps_auth.db import get_user_db  # type: ignore
+from fps_auth.models import UserRead  # type: ignore
 
 from .models import Terminal
-from .server import TerminalServer
+
+if os.name == "nt":
+    from .win_server import TerminalServer  # type: ignore
+else:
+    from .server import TerminalServer  # type: ignore
 
 router = APIRouter()
 
@@ -25,7 +29,7 @@ async def get_terminals():
 
 @router.post("/api/terminals")
 async def create_terminal(
-    user: User = Depends(current_user),
+    user: UserRead = Depends(current_user),
 ):
     name = str(len(TERMINALS) + 1)
     terminal = Terminal(
@@ -42,9 +46,10 @@ async def create_terminal(
 @router.delete("/api/terminals/{name}", status_code=204)
 async def delete_terminal(
     name: str,
-    user: User = Depends(current_user),
+    user: UserRead = Depends(current_user),
 ):
-    TERMINALS[name]["server"].quit()
+    for websocket in TERMINALS[name]["server"].websockets:
+        TERMINALS[name]["server"].quit(websocket)
     del TERMINALS[name]
     return Response(status_code=HTTPStatus.NO_CONTENT.value)
 
@@ -61,7 +66,7 @@ async def terminal_websocket(
         accept_websocket = True
     else:
         cookie = websocket._cookies["fastapiusersauth"]
-        user = await cookie_authentication(cookie, user_db)
+        user = await get_jwt_strategy().read_token(cookie, user_db)
         if user:
             accept_websocket = True
     if accept_websocket:
@@ -69,7 +74,8 @@ async def terminal_websocket(
         await TERMINALS[name]["server"].serve(websocket)
         if name in TERMINALS:
             TERMINALS[name]["server"].quit(websocket)
-            del TERMINALS[name]
+            if not TERMINALS[name]["server"].websockets:
+                del TERMINALS[name]
     else:
         await websocket.close(code=status.WS_1008_POLICY_VIOLATION)
 
